/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#pragma once
#ifndef IFRTP_H_
#define IFRTP_H_

#include <linux/types.h>
#include <linux/inet.h>
#include <linux/ip.h>
#include <linux/ipv6.h>
#include <linux/tcp.h>
#include <linux/udp.h>
#include <linux/icmp.h>
#include <linux/igmp.h>
#include <linux/if_arp.h>
#include <linux/skbuff.h>
#include <linux/debugfs.h>
#include <linux/of_platform.h>

#include "ifrtp_logging.h"
#include "igw_driver.h"

#define IGE_IFNAME "igw"
#define IFRTP_IFNAME "ivfrtp"

#define IFRTP_STREAM_BUFFER_MEMAP_NUM_STREAM_TYPE 3

#define ifrtp_dev_dbg(dev, fmt, ...)	\
({										\
	if (ifrtp_cfg.debug)				\
	dev_info(dev, fmt, ##__VA_ARGS__);	\
})

#define ifrtp_pr_debug(fmt, ...)	\
({									\
	if (ifrtp_cfg.debug)			\
	pr_info(fmt, ##__VA_ARGS__);	\
})

#define ifrtp_pr_debug_ratelimited(fmt, ...)	\
({												\
	if (ifrtp_cfg.debug)						\
	pr_info_ratelimited(fmt, ##__VA_ARGS__);	\
})

struct rtp_recv_buffer_memmap {
	u32 start_addr;
	u32 ch_offset;
	u32 size;
};

struct ifrtp_config {
	u32 timeout_warn_ns_ioctl;
	u32 timeout_ioctl_debugfs_counter;
	u32 arp_timeout_ms;
	u32 target_ip;
	u32 source_ip;
	u16 tx_buffer;
	u16 rx_buffer;
	u16 tx_write_batch;
	u16 rx_write_batch;
	u32 rtp_poll_weight;
	u32 stream_buffer_packet_size;
	struct rtp_recv_buffer_memmap rtp_recv_buffer[6];
	unsigned int rx_coalesce_usecs;
	unsigned int main_mac_mask;
	int numvfs;
	int numphys;
	bool debug;

	struct igw_driver_handle *driver_handle;
};

struct ifrtp_global {
	struct ifrtp_config *cfg;
	int irq;
};

#endif  // IFRTP_H_
