/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#ifndef IFRTP_ADDRESS_H_
#define IFRTP_ADDRESS_H_

#define IFRTP_RES_INDEX_FPGA                0
#define IFRTP_RES_INDEX_LED                 1

// Module top address
// stream, packet pack/unpcak, identification, validation, discard, packet counter, vbp, extraction
#define FPGA_NET_PROCESS_TOP             0x00080000
#define FPGA_RECEIVER_SYSTEM_TOP         0x00000000
#define FPGA_TRANS_SYSTEM_TOP            0x00040000
#define FPGA_NET_TRM_TOP                 0x000A0000
#define FPGA_MII_COMMON                  0x000C0000


// Sub Module top address and offset
#define FPGA_IRQ_L1_TOP                 (FPGA_NET_PROCESS_TOP + 0xC000)

// TX & RX
#define IFRTP_TX                        (FPGA_NET_PROCESS_TOP + 0x00E0)

#ifdef IFRTP_USE_COR
#define IFRTP_RX                        (FPGA_NET_PROCESS_TOP + 0x00030000)
#else
#define IFRTP_RX                        (FPGA_NET_PROCESS_TOP + 0x000040E0)
#endif

// works on both TX and RX
#define IFRTP_OFFSET_DESCRIPTOR_DAH     0x00
#define IFRTP_OFFSET_DESCRIPTOR_DAL     0x04
#define IFRTP_OFFSET_DESCRIPTOR_DEPTH   0x08
#define IFRTP_OFFSET_DESCRIPTOR_WP      0x10
#define IFRTP_OFFSET_DESCRIPTOR_RP      0x14

// Packet Counter
#define IFRTP_TX_PKT_COUNTER            (FPGA_NET_PROCESS_TOP + 0x00000400)
#define IFRTP_RX_PKT_COUNTER            (FPGA_NET_PROCESS_TOP + 0x00004400)
#define IFRTP_RX_PKT_COUNTER_SUBOFFSET               0x00004000

#define IFRTP_PKT_COUNTER_TYPE_MAX                   16
#define IFRTP_PKT_COUNTER_EXIST_MASK                 0xFFFF
#define IFRTP_OFFSET_PKT_COUNTER_TICK                0x00
#define IFRTP_OFFSET_PKT_COUNTER_FTICK               0x04
#define IFRTP_OFFSET_PKT_COUNTER_EXIST               0x0C
// #define IFRTP_OFFSET_PKT_COUNTER_SEL_TYPE            0x40
// #define IFRTP_OFFSET_PKT_COUNTER_SEL_TYPE_OFFSET     0x04
#define IFRTP_OFFSET_PKT_COUNTER_PKTCNT              0x80
// #define IFRTP_OFFSET_PKT_COUNTER_PKTCNT_OFFSET       0x04
// #define IFRTP_OFFSET_PKT_COUNTER_PKTSIZ              0xC0
// #define IFRTP_OFFSET_PKT_COUNTER_PKTSIZ_OFFSET       0x04


#define IFRTP_OFFSET_SFP_LINKSTATE          0x94
#define IFRTP_OFFSET_SFP_LINKSTATE_CH       (-0x4)
#define IFRTP_SFP_LINKSTATE_BIT             (1<<16)

#endif /* IFRTP_ADDRESS_H_ */
