/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#ifndef IFRTP_DRIVER_H_
#define IFRTP_DRIVER_H_
#include <linux/netdevice.h>
#include <linux/irqreturn.h>
#include <linux/inetdevice.h>
#include <net/route.h>
#include "ifrtp_ioctl.h"
#include "ifrtp_address.h"

#define IFRTP_NUMVFS_MAX 24

#define RTP_SSRC_MAX        28
#define RTP_SSRC_PER_CH     3
#define RTP_QFHD_CH_PER_ST  4
#define RTP_MIN_PACKET_SIZE 8
#define RTP_MAX_PACKET_SIZE 1536


struct ifrtp_recv_mem {
	uintptr_t addr;
	uintptr_t begin;
	uintptr_t end;
	uintptr_t begin_offset;
};

struct ifrtp_priv {
	struct net_device_stats stats;

	spinlock_t *tx_desc_lock;
	u32 *desc_addr_tx;
	u32 *desc_addr_rx;
	struct dma_chan *dmachan;

	struct ifrtp_recv_mem *recv_buff;
	u32 ssrc_count[RTP_SSRC_PER_CH];

	struct net_device *dev;
	u32 stream_id;
	u64 saddr;
	unsigned int stream_mode;
	bool is_main_mac;
};

struct ifrtp_packet_count {
	u32 packet_count[16];
	u32 packet_size[16];
};

extern struct net_device *ifrtp_devs[];
int ifrtp_init_driver(int numvfs);
void ifrtp_cleanup_driver(void);
irqreturn_t ifrtp_napi_schedule(void);
int arp_query(__be32 paddr, int igw_if_id, char *eth_dst);
void ifrtp_init_rtp_recv_buffer(struct ifrtp_priv *priv);

#endif  // IFRTP_DRIVER_H_
