/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#ifndef IFRTP_IOCTL_H_
#define IFRTP_IOCTL_H_

#include <linux/types.h>

#ifndef __KERNEL__
#include <stdint.h>
#include <stdbool.h>
#include <stdlib.h>
#endif

#define IFRTP_MEMMAP_FHD             0
#define IFRTP_MEMMAP_QFHD            1
#define IFRTP_MEMMAP_NUMBER_OF_TYPES 2

struct _ifrtp_ioc_config {
	unsigned int  cmd;
	char         *data;
};

struct _ifrtp_ssrc_config {
	const __u32 *ssrc_vec;
	int         v_count;
	int         a_count;
	int         m_count;
};

struct ifrtp_msghdr {
	uintptr_t msg_addr; /* physical address */
	size_t    msg_len;  /* message length */
	__u32     ssrc;     /* message ssrc, only for recv */
};


#define IFRTP_IOC_MAGIC    0xB1

#define IFRTP_IOCGIFADDR              _IOR(IFRTP_IOC_MAGIC, 0x25, struct sockaddr_in)
#define IFRTP_IOCSIFADDR              _IOW(IFRTP_IOC_MAGIC, 0x26, struct sockaddr_in)
#define IFRTP_IOCGIFDSTADDR           _IOR(IFRTP_IOC_MAGIC, 0x27, struct sockaddr_in)
#define IFRTP_IOCSIFDSTADDR           _IOW(IFRTP_IOC_MAGIC, 0x28, struct sockaddr_in)
#define IFRTP_IOCGIFSRCADDR           _IOR(IFRTP_IOC_MAGIC, 0x29, struct sockaddr_in)
#define IFRTP_IOCGIFSELMAC            _IOR(IFRTP_IOC_MAGIC, 0x2A, unsigned int)
#define IFRTP_IOCSIFSELMAC            _IOW(IFRTP_IOC_MAGIC, 0x2B, unsigned int)
#define IFRTP_IOCSIFMMAPMOD           _IOW(IFRTP_IOC_MAGIC, 0x2E, unsigned int)
#define IFRTP_IOCSIFSSRC              _IOW(IFRTP_IOC_MAGIC, 0x2F, struct _ifrtp_ssrc_config)
#define IFRTP_IOCSOFFSETV             _IOW(IFRTP_IOC_MAGIC, 0x30, unsigned int)
#define IFRTP_IOCGPLSSFLG             _IOR(IFRTP_IOC_MAGIC, 0x31, unsigned int)

#ifdef __KERNEL__
#include <linux/netdevice.h>
int ifrtp_ioctl(struct net_device *dev, struct ifreq *ifr, int cmd);
#endif

#endif // IFRTP_IOCTL_H_
