/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#ifndef IGW_DRIVER_H_
#define IGW_DRIVER_H_

#include <linux/module.h>
#include <linux/kernel.h>
#include <linux/etherdevice.h>
#include <linux/proc_fs.h>

#include <linux/version.h>
#include <linux/netdevice.h>
#include <linux/if_ether.h>
#include <linux/ethtool.h>

#include <linux/ioctl.h>
#include <linux/netdevice.h>

#include <linux/version.h>
#include <linux/mii.h>
#include <linux/netdevice.h>
#include <linux/spinlock_types.h>
#include <linux/interrupt.h>

#include "ifrtp.h"

#define IFRTP_SDI_CH_MAX_PER_CORE 8
#define IFRTP_FILTER_MAX_FOR_FW_PER_CORE 16

#ifdef IFRTP_USE_COR
#define IFRTP_PHY_COUNT        2
#else
#define IFRTP_PHY_COUNT        1
#endif

int igw_net_ether_setup(struct net_device *dev, const char *drv_name);
int igw_net_ether_release(struct net_device *dev);

struct igw_driver_handle;
struct ifrtp_link_check_queue_work;
struct igw_priv {
	struct igw_driver_handle *handle;

	int core_index;
	int netif_index;

	int netif_priority;

	struct NetdevArch {
		u32 msg_enable;
		struct net_device_stats stats;
		struct net_device *dev;
		spinlock_t lock;
		struct timer_list link_check_timer;
		struct ifrtp_link_check_queue_work *link_check_queue_work;

		struct EthConfig {
			bool speed_autodetect_target;
			int speed_target;
			int speed_target_auto;
		} eth_config;
	} __netarch;

	struct FilterInfo {
		unsigned int port;
		bool netfilter;
	} filter[IFRTP_FILTER_MAX_FOR_FW_PER_CORE];
	int last_nf_slot, last_ephemeral_slot;
};

struct igw_driver_handle {
	int core_index_max;
	int netif_index_max;
	struct net_device *netdev[2];
	struct igw_priv *dev[2];

	bool raw_packet_received;
	struct tasklet_struct tasklet_raw_packet;

	resource_size_t regs_start;
	void __iomem *regs;
	void __iomem *led_regs;

};

struct ifrtp_link_check_queue_work {
	struct work_struct work;
	struct igw_priv *dev;
};

int ifrtp_driver_start(void);

irqreturn_t ifrtp_driver_tasklet_schedule(void);
int igw_net_raw_packet_isr(struct igw_priv *dev);

#endif  // IGW_DRIVER_H_
