/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#ifndef IGW_NET_ADDRESS_H_
#define IGW_NET_ADDRESS_H_

#include "ifrtp_address.h"

#define OFFSET_IRQ_L2_NET_TOP           (FPGA_NET_PROCESS_TOP    + 0x0000c000)
#define OFFSET_IRQ_L2_NET_ENABLE        (OFFSET_IRQ_L2_NET_TOP     + 0x00)
#define OFFSET_IRQ_L2_NET_STATUS        (OFFSET_IRQ_L2_NET_TOP     + 0x08)

//============================================================================
// Transmitter System
//============================================================================
// ## Transmitter System #####################################################
#define OFFSET_NETTX_TRANS_SYS_TOP        (FPGA_TRANS_SYSTEM_TOP + 0x00000000)

// Transmitter System Member offset
#define OFFSET_NETTX_TRANS_SYS_EN                                   0x00000000
#define OFFSET_NETTX_TRANS_SYS_QUEUE_SPACE                          0x00000004
#define OFFSET_NETTX_TRANS_SYS_BUFFER_OFFSET                        0x00000008
#define OFFSET_NETTX_TRANS_SYS_BUFFER_SPACE                         0x0000000C
#define OFFSET_NETTX_TRANS_SYS_BUFFER_UPDATE                        0x0000000C
#define OFFSET_NETTX_TRANS_SYS_BUFFER                               0x00020000


//============================================================================
// Reciever System
//============================================================================
// ## Reciever System ########################################################
#define OFFSET_RECV_SYSTEM_TOP         (FPGA_RECEIVER_SYSTEM_TOP + 0x00000000)

// Reciever System Member offset
#define OFFSET_RECV_SYSTEM_QUEUE_LEVEL                              0x00000004
#define OFFSET_RECV_SYSTEM_BUFFER_OFFSET                            0x00000008
#define OFFSET_RECV_SYSTEM_BUFFER_LEVEL                             0x0000000C
#define OFFSET_RECV_SYSTEM_BUFFER_UPDATE                            0x0000000C
#define OFFSET_RECV_SYSTEM_BUFFER                                   0x00020000
#define OFFSET_RECV_SYSTEM_BUFFER_ADDR_MASK                         0x0001FFFF


//============================================================================
// Network module
//============================================================================
// ## Packet Unpack Tx #######################################################
#define OFFSET_NETTX_PKT_UNPACK_TOP        (FPGA_NET_PROCESS_TOP + 0x00000000)

// Packet Unpack Tx Unpack Enable offset
#define OFFSET_NETTX_PKT_UNPACK_EN                                  0x00000010

// ## Packet Pack Tx #########################################################
#define OFFSET_NETTX_PKT_PACK_TOP          (FPGA_NET_PROCESS_TOP + 0x00000040)
#define OFFSET_NETTX_PKT_PACK_SIZE                                  0x00000020
#define OFFSET_NETTX_PKT_PACK_MAX                                            2

// Packet Pack Enable
#define OFFSET_NETTX_PKT_PACK_EN_TOP                                0x00000010

// Packet Pack Enable Member offset
#define OFFSET_NETTX_PKT_PACK_EN_ENABLE                             0x00000000

// ## Discard Tx #############################################################
#define OFFSET_NETTX_DISCARD_TOP           (FPGA_NET_PROCESS_TOP + 0x00000100)
#define OFFSET_NETRX_DISCARD_TOP           (FPGA_NET_PROCESS_TOP + 0x00004100)

// Discard Tx Control Member offset
#define OFFSET_NET_DISCARD_CTL_DISCARD_EN                           0x00000000
#define OFFSET_NET_DISCARD_CTL_ALL_DISCARD_EN                       0x00000004

// Discard Tx Control
#define OFFSET_NETTX_DISCARD_CTL_TOP                                0x00000000
#define OFFSET_NETTX_DISCARD_CTL_SIZE                               0x00000100
#define OFFSET_NETTX_DISCARD_CTL_MAX                                         2

// Discard Rx Control
#define OFFSET_NETRX_DISCARD_CTL_TOP                                0x00000000
#define OFFSET_NETRX_DISCARD_CTL_SIZE                               0x00004000
#define OFFSET_NETRX_DISCARD_CTL_MAX                                         2

// ## Tx VBP  #################################################################
#define OFFSET_NETTX_VBP_TOP               (FPGA_NET_PROCESS_TOP + 0x00001000)
// Tx VBP Duplicate Filter
#define OFFSET_NETTX_VBP_DUPLICAT_FILTER_TOP                        0x00000000
#define OFFSET_NETTX_VBP_DUPLICAT_FILTER_SIZE                       0x00000040
#define OFFSET_NETTX_VBP_DUPLICAT_FILTER_MAX                                24

// Tx VBP Duplicate Filter Member offset
#define OFFSET_NETTX_VBP_DUPLICAT_FILTER_CTL                        0x00000000
#define OFFSET_NETTX_VBP_DUPLICAT_FILTER_DST_MAC                    0x00000004
#define OFFSET_NETTX_VBP_DUPLICAT_FILTER_SRC_MAC                    0x00000000
#define OFFSET_NETTX_VBP_DUPLICAT_FILTER_IP_SRC1                    0x00000008
#define OFFSET_NETTX_VBP_DUPLICAT_FILTER_IP_DST1                    0x00000014
#define OFFSET_NETTX_VBP_DUPLICAT_FILTERP_UDP_PORT                  0x00000018

#define OFFSET_NETTX_VBP_DEFAULT_MAC_TYPE_TOP                       0x00000800
#define OFFSET_NETTX_VBP_DEFAULT_MAC_TYPE_EN                        0x00000000
#define OFFSET_NETTX_VBP_MAC_TYPE_BYPASS_TOP                        0x00000810
#define OFFSET_NETTX_VBP_MAC_TYPE_BYPASS_EN                         0x00000000
#define OFFSET_NETTX_VBP_COMMON_HEADER                              0x00000880

// ## Tx RTP Sub  #################################################################
#define OFFSET_NETTX_RTP_SUB_TOP               (FPGA_NET_PROCESS_TOP + 0x00001000)
// Tx RTP Sub  Duplicate Filter Member offset
#define OFFSET_NETTX_RTP_SUB_CTL                                        0x00000000
// #define OFFSET_NETTX_RTP_SUB_DST_MAC                                    0x00000004  // DestMAC Top
#define OFFSET_NETTX_RTP_SUB_SRC_MAC                                    0x00000000  // SrcMAC Top
#define OFFSET_NETTX_RTP_SUB_IP_SRC1                                    0x00000008
#define OFFSET_NETTX_RTP_SUB_FILTER_MAC0                                0x00000010
#define OFFSET_NETTX_RTP_SUB_FILTER_MAC1                                0x00000014

#define OFFSET_NETTX_RTP_SUB_COMMON_HEADER                              0x00000000

// ## Stream Transmitter #####################################################
#define OFFSET_NETTX_STRM_TRANS_TOP        (FPGA_NET_PROCESS_TOP + 0x00002000)
// Stream Transmitter Channel offset(#0-#23)
#define OFFSET_NETTX_STRM_TRANS_CH_TOP                              0x00000000
#define OFFSET_NETTX_STRM_TRANS_CH_SIZE                             0x00000040
#define OFFSET_NETTX_STRM_TRANS_CH_MAX                                      24

// Stream Transmitter Channel Member offset
#define OFFSET_NETTX_STRM_TRANS_CH_DST_MAC                          0x00000004  // DestMAC Top
#define OFFSET_NETTX_STRM_TRANS_CH_SRC_MAC                          0x00000000  // SrcMAC TOp
#define OFFSET_NETTX_STRM_TRANS_CH_VLAN_TAG                         0x00000000
#define OFFSET_NETTX_STRM_TRANS_CH_IP_HEAD                          0x00000010
#define OFFSET_NETTX_STRM_TRANS_CH_IP_SRC1                          0x00000008
#define OFFSET_NETTX_STRM_TRANS_CH_IP_DST1                          0x00000014
#define OFFSET_NETTX_STRM_TRANS_CH_UDP_PORT                         0x00000018

// Stream Transmitter Channnel Control offset
#define OFFSET_NETTX_STRM_TRANS_CH_CTL_TOP                          0x00001000

// Stream Transmitter Channnel Control Member offset
#define OFFSET_NETTX_STRM_TRANS_CH_CTL_CH_EN                        0x00000000
#define OFFSET_NETTX_STRM_TRANS_CH_CTL_INPLICIT_TYPE                0x00000010
#define OFFSET_NETTX_STRM_TRANS_CH_CTL_IPV6_HEADER                  0x00000020
#define OFFSET_NETTX_STRM_TRANS_CH_CTL_IPVER_SELECT                 0x00000030
#define OFFSET_NETTX_STRM_TRANS_CH_CTL_UNREC_CH_CNT                 0x00000040
#define OFFSET_NETTX_STRM_TRANS_CH_CTL_DISABLED_CH_CNT              0x00000050
#define OFFSET_NETTX_STRM_TRANS_CH_CTL_OVERSIZED_CH_CNT             0x00000060

// Stream Transmitter Common Header
#define OFFSET_NETTX_STRM_TRANS_COMMON_SRC  (OFFSET_NETTX_STRM_TRANS_CH_CTL_TOP + 0x80)


// ## Packet Unpack Rx #######################################################
#define OFFSET_NETRX_UNPACK_TOP            (FPGA_NET_PROCESS_TOP + 0x00004000)
// Packet Unpack Rx Control
#define OFFSET_NETRX_UNPACK_CTL_TOP                                 0x00000000
#define OFFSET_NETRX_UNPACK_CTL_SIZE                                0x00004000
#define OFFSET_NETRX_UNPACK_CTL_MAX                                          2

// Packet Unpack Rx Control Member offset
#define OFFSET_NETRX_UNPACK_CTL_UNPACKED_TYPE_CNT                   0x00000010
#define OFFSET_NETRX_UNPACK_CTL_RESET                               0x00000014

// ## Packet Pack Rx #########################################################
#define OFFSET_NETRX_PKT_PACK_TOP          (FPGA_NET_PROCESS_TOP + 0x00004040)
// Packet Pack Rx Control
#define OFFSET_NETRX_PKT_PACK_CTL_TOP                               0x00000000
#define OFFSET_NETRX_PKT_PACK_CTL_SISE                              0x00004000
#define OFFSET_NETRX_PKT_PACK_CTL_MAX                                        2

// Packet Pack Rx Member offset
#define OFFSET_NETRX_PKT_PACK_CTL_UNREC_NEXT_HEADER_CNT             0x00000000
#define OFFSET_NETRX_PKT_PACK_CTL_UNREC_FRAME_TYPE_CNT              0x00000004
#define OFFSET_NETRX_PKT_PACK_CTL_PKT_SIZE_MISMATCH_CNT             0x00000008
#define OFFSET_NETRX_PKT_PACK_CTL_DUMPED_PKT_CNT                    0x0000000C
#define OFFSET_NETRX_PKT_PACK_CTL_PACK_EN                           0x00000010

// ## Validation Rx ##########################################################
#define OFFSET_NETRX_VALIDATE_TOP          (FPGA_NET_PROCESS_TOP + 0x00004080)
// Validation Rx Control
#define OFFSET_NETRX_VALIDATE_CTL_TOP                               0x00000000
#define OFFSET_NETRX_VALIDATE_CTL_SIZE                              0x00004000
#define OFFSET_NETRX_VALIDATE_CTL_MAX                                        2

// Validation Rx Control Membler offset
#define OFFSET_NETRX_VALIDATE_CTL_PKT_DISCARD_FLG                   0x0000000C
#define OFFSET_NETRX_VALIDATE_CTL_PKT_LEN_ERR_DISCARD_FLG           0x00000010
#define OFFSET_NETRX_VALIDATE_CTL_IP_CHK_CNT                        0x00000020
#define OFFSET_NETRX_VALIDATE_CTL_TCP_CHK_CNT                       0x00000024
#define OFFSET_NETRX_VALIDATE_CTL_UDP_CHK_CNT                       0x00000028
#define OFFSET_NETRX_VALIDATE_CTL_PKT_DISCARD_CNT                   0x0000002C
#define OFFSET_NETRX_VALIDATE_CTL_PKT_LEN_ERR_CNT                   0x00000030

// ## Payload Extraction Rx ##################################################
#define OFFSET_NETRX_PAYLOAD_EXTRACT_TOP   (FPGA_NET_PROCESS_TOP + 0x000040C0)
// Payload Extraction Rx Control
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_TOP                        0x00000000
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_SIZE                       0x00004000
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_MAX                                 2

// Payload Extraction Rx Member offset
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_EXTRACT_FLG_EN             0x00000000
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_EXTRACT_DUAL_TYPE          0x00000004
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_EXTRACT_DEFAULT_MEDIA_TYPE 0x00000008
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_EXTRACT_DEFAULT_PASS       0x0000000C
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_EXTRACT_MEDIA_TYPE         0x00000010
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_EXTRACT_PACKET_TYPE        0x00000014
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_EXTRACT_SYNC_SOURCE        0x00000018
#define OFFSET_NETRX_PAYLOAD_EXTRACT_CTL_PKT_LOSS_MONITOR           0x0000001c

// ## Idetification Rx #######################################################
#define OFFSET_NETRX_IDENT_TOP             (FPGA_NET_PROCESS_TOP + 0x00006000)
// Idetification Rx Control
#define OFFSET_NETRX_IDENT_CTL_TOP                                  0x00000000
#define OFFSET_NETRX_IDENT_CTL_SIZE                                 0x00004000
#define OFFSET_NETRX_IDENT_CTL_MAX                                           2

// Idetification Rx Control Member offset
#define OFFSET_NETRX_IDENT_CTL_FILTER_EN                            0x00000000
#define OFFSET_NETRX_IDENT_CTL_SRC_IP_FILTER_EN                     0x00000004
#define OFFSET_NETRX_IDENT_CTL_DST_IP_FILTER_EN                     0x00000008
#define OFFSET_NETRX_IDENT_CTL_DST_PORT_FILTER_EN                   0x0000000C

#define OFFSET_NETRX_IDENT_CTL_FIREWALL_FILTER_EN                   0x00000060
#define OFFSET_NETRX_IDENT_CTL_FIREWALL_FILTER_DST_ADDR_LOW         0x00000064
#define OFFSET_NETRX_IDENT_CTL_FIREWALL_FILTER_DST_ADDR_HIGH        0x00000068
#define OFFSET_NETRX_IDENT_CTL_FIREWALL_FILTER_PKT_TYPE             0x0000006c

#define OFFSET_NETRX_IDENT_CTL_PKT_FILTER_TYPE_DEF                  0x0000007C
#define OFFSET_NETRX_IDENT_CTL_PKT_FILTER_TYPE_TOP                  0x00000080
#define OFFSET_NETRX_IDENT_CTL_PKT_FILTER_TYPE_SIZE                 0x00000004
#define OFFSET_NETRX_IDENT_CTL_PKT_FILTER_TYPE_MAX                          32

#define OFFSET_NETRX_IDENT_CTL_ADDR_TOP                             0x00000800
#define OFFSET_NETRX_IDENT_CTL_ADDR_SIZE                            0x00000040

#define OFFSET_NETRX_IDENT_CTL_ADDR_DST_IP                          0x00000010

#define OFFSET_NETRX_IDENT_CTL_ADDR_DST_PORT                        0x00000020

// ## XGMac Rx ###############################################################
#define OFFSET_NETRX_XGMAC_TOP             (FPGA_NET_PROCESS_TOP + 0x00040400)
// XGMac Rx Control
#define OFFSET_NETRX_XGMAC_CTL_TOP                                  0x00000000
#define OFFSET_NETRX_XGMAC_CTL_SIZE                                 0x00000400
#define OFFSET_NETRX_XGMAC_CTL_MAX                                           2

// XGMac Rx Control Member offset
#define OFFSET_NETRX_XGMAC_CTL_RECV_MAX_PKT_SIZE                    0x00000010
#define OFFSET_NETRX_XGMAC_CTL_RECV_INVERT_CRC                      0x00000020
#define OFFSET_NETRX_XGMAC_CTL_TRNS_INTER_FRM_GAP                   0x00000024
#define OFFSET_NETRX_XGMAC_CTL_TRNS_FRAME_SIZE                      0x00000040
#define OFFSET_NETRX_XGMAC_CTL_TRNS_INVERT_CRC                      0x00000044
#define OFFSET_NETRX_XGMAC_CTL_RECV_CRC_ERR_CNT                     0x0000004C
#define OFFSET_NETRX_XGMAC_CTL_RECV_FRM_TOO_SHORT_CNT               0x00000050
#define OFFSET_NETRX_XGMAC_CTL_RECV_FRM_TOO_LONG_CNT                0x00000054
#define OFFSET_NETRX_XGMAC_CTL_ERR_FRM_CNT                          0x00000058
#define OFFSET_NETRX_XGMAC_CTL_RECV_FIFO_OVER_CNT                   0x0000005C
#define OFFSET_NETRX_XGMAC_CTL_TRNS_FRM_TOO_SHORT_CNT               0x00000064
#define OFFSET_NETRX_XGMAC_CTL_TRNS_FRM_TOO_LONG_CNT                0x00000068
#define OFFSET_NETRX_XGMAC_CTL_TRNS_SEGMENT_INVALID_CNT             0x0000006C
#define OFFSET_NETRX_XGMAC_CTL_FRM_UNDER_CNT                        0x00000070
#define OFFSET_NETRX_XGMAC_CTL_RECV_GOOD_FRM_UPPER_CNT              0x00000080
#define OFFSET_NETRX_XGMAC_CTL_RECV_GOOD_FRM_LOWER_CNT              0x00000084
#define OFFSET_NETRX_XGMAC_CTL_TRNS_GOOD_FRM_UPPER_CNT              0x00000088
#define OFFSET_NETRX_XGMAC_CTL_TRNS_GOOD_FRM_LOWER_CNT              0x0000008c

//============================================================================
// Traffic Manager
//============================================================================
// ## TRM Rx #################################################################
#define OFFSET_TRM_RX_TOP                      (FPGA_NET_TRM_TOP + 0x00000000)

// GMAC SFP
#define OFFSET_NET_GMAC_CTL_MDIO_ACCESS                          0x00000030
#define OFFSET_NET_GMAC_CTL_MDIO_SETUP_CLK                       0x00000034

#define OFFSET_NET_SFP_DEBUG_TOP        (FPGA_NET_PROCESS_TOP + 0x00040000)
#define OFFSET_NET_GMAC_TOP             (FPGA_NET_PROCESS_TOP + 0x00040400)
#define OFFSET_NET_GMAC_CTL_TOP                                  0x00000000
#define OFFSET_NET_GMAC_CTL_SIZE                                 0x00000400
#define OFFSET_NET_GMAC_CTL_MAX                                           2


#endif /* IGW_NET_ADDRESS_H_ */
