/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#ifndef IGW_NETWORK_H_
#define IGW_NETWORK_H_

#include "igw_driver.h"

#define NN_NWK_PKT_TYPE_MAX 24

#define RX_TYPE_FIREWALL_FILTER 0x1d
#define TX_TYPE_MAIN            0x1e
#define RX_TYPE_MAIN            TX_TYPE_MAIN

// Stream Transmitter Channel Init
struct IocStrmTrnsCnlInitConfig {
	int           ch_no;
	unsigned char eth_dst[6];
	unsigned char eth_src[6];
	unsigned int  vlan_tag;
	unsigned int  ttl;
	unsigned int  ipv6_flow;
	unsigned int  ip_src_addr[4];
	unsigned int  ip_dst_addr[4];
	unsigned int  udp_port;
};

// Stream Transmitter Channnel Control Init
struct IocStrmTrnsCnlCtlInitConfig {
	unsigned int channel_enable;
	unsigned int inplicit_type;
	unsigned int ipv6_header;
	unsigned int ipver_select;
	unsigned int unrecognized_ch_count;
	unsigned int disabled_ch_count;
	unsigned int oversized_pkt_count;
};

// Packet Unpack Enable Init
struct IocPktUnpackTxDirInitConfig {
	unsigned int unpack_enable;
};

// Tx VBP Default MAC Type Init
struct IocTxVbpDefaultMacTypeInitConfig {
	unsigned int default_mac_type;
};

// Tx VBP MAC Type bypass Init
struct IocTxVbpMacTypeBypassInitConfig {
	unsigned int mac_type_bypass;
};

// Packet Pack Init
struct IocPktPackTxDirInitConfig {
	int          packet_pack_no;
	unsigned int pack_enable;
};

// Packet Unpack Rx Init
struct IocPktUnpackRxInitConfig {
	int          area_no;
	unsigned int unrecognized_next_header_cnt;
	unsigned int unrecognized_frame_type_cnt;
	unsigned int packet_size_mismatch_cnt;
	unsigned int dumped_packet_cnt;
	unsigned int unpack_every_type;
};

// Packet Identification Rx Init
struct IocIdentificationRxInitConfig {
	int          area_no;
	int          page;
	unsigned int pkt_filter_en;
	unsigned int src_ip_addr_en;
	unsigned int dst_ip_addr_en;
	unsigned int dst_port_en;
	unsigned int unmatched_type;
	unsigned int ch_type[32];
};

// Packet Validation Rx Init
struct IocPktValidationRxInitConfig {
	int          area_no;
	int          page;
	unsigned int ip_header_chksum_en;
	unsigned int tcp_chksum_en;
	unsigned int udp_chksum_en;
	unsigned int chksum_err_discard_en;
	unsigned int pktlen_err_discard_en;
};

// Packet Discard Init
struct IocDiscardInitConfig {
	int          area_no;
	int          page;
	unsigned int discard_en;
};

// Packet Pack Rx Init
struct IocPktPackRxInitConfig {
	int          area_no;
	unsigned int unrecognized_next_header_cnt;
	unsigned int unrecognized_frame_type_cnt;
	unsigned int packet_size_mismatch_cnt;
	unsigned int dumped_packet_cnt;
	unsigned int no_packing;
};

// Payload Extraction Rx Init
struct IocPayloadExtractionRxInitConfig {
	int          area_no;
	int          page;
	unsigned int all_type_en;
	unsigned int default_type;
	unsigned int enable_default_type;
	unsigned int header_en;
	unsigned int preview_en;
};

struct IocPayloadExtractionRxSSRCConfig {
	int          area_no;
	unsigned int dual_en;
	unsigned int media_type;
	unsigned int nwk_pkt_type;
	unsigned int ssrc;
};

// for Tx Ip dest address set
struct IocNetTxDestIpAddressConfig {
	unsigned int ch_no;
	unsigned int ip_dst_addr;
};

// for Rx Ip dest address set
struct IocNetRxDestIpAddressConfig {
	unsigned int module_no;
	unsigned int filter_no;
	unsigned int ip_dst_addr;
};

// for Tx Ip src address set
struct IocNetTxSourceIpAddressConfig {
	unsigned int ch_no;
	unsigned int ip_dst_addr;
};

// for Tx Ip src/dst port set
struct IocNetTxPortConfig {
	unsigned int ch_no;
	unsigned int port;
};

// for Rx filter enable disable set
struct IocNetTxDuplicateEnableConfig {
	unsigned int ch_no;
	unsigned int enable;
};

// for Rx Ip src/dst port set
struct IocNetRxPortConfig {
	unsigned int module_no;
	unsigned int filter_no;
	unsigned int port;
};

// for Tx Discard enable set
struct IocNetTxDiscardConfig {
	unsigned int ch_no;
	unsigned int enable;
	unsigned int is_primary;
};

// for Rx Discard enable set
struct IocNetRxDiscardConfig {
	unsigned int filter_no;
	unsigned int enable;
	unsigned int is_redundancy;
};

// for Tx Mac dest address set
struct IocNetTxDestMacAddressConfig {
	unsigned int  ch_no;
	unsigned char eth_dst[6];
};


// for Tx Mac source address set
struct IocNetTxSourceMacAddressConfig {
	unsigned int  ch_no;
	unsigned char eth_src[6];
};

struct IocNetRxTrmCtrlBucketInitConfig {
	unsigned int nwk_pkt_type;
};

// For Get Rx Sequence Number Error Status.
struct IocNetRxSequenceNumberErrorStatusConfig {
	unsigned int engine_no;
	unsigned int sequence_number_error;
	unsigned int sequence_number_error_mask;
};

//--------------------------------------------------
// Init
//--------------------------------------------------
void ifrtp_init_network_device_tx(struct igw_priv *dev);
void ifrtp_init_network_device_rx(struct igw_priv *dev);
//--------------------------------------------------
// Unpack
//--------------------------------------------------
int ifrtp_set_tx_pkt_unpack(struct igw_priv *dev, struct IocPktUnpackTxDirInitConfig *config);
int ifrtp_set_rx_pkt_unpack(struct igw_priv *dev, struct IocPktUnpackRxInitConfig *config);
int ifrtp_reset_unpack(struct igw_priv *dev);

//--------------------------------------------------
// Pack
//--------------------------------------------------
int ifrtp_set_tx_pkt_pack(struct igw_priv *dev, struct IocPktPackTxDirInitConfig *config);
int ifrtp_set_rx_pkt_pack(struct igw_priv *dev, struct IocPktPackRxInitConfig *config);

//--------------------------------------------------
// Discard
//--------------------------------------------------
int ifrtp_set_tx_discard(struct igw_priv *dev, struct IocDiscardInitConfig *config);
int ifrtp_set_tx_discard_by_devindex(struct igw_priv *dev, bool enable);
int ifrtp_set_tx_discard_all(struct igw_priv *dev, bool enable);
int ifrtp_set_rx_discard(struct igw_priv *dev, struct IocDiscardInitConfig *config);
int ifrtp_set_rx_discard_by_devindex(struct igw_priv *dev, bool enable);
int ifrtp_set_rx_discard_all(struct igw_priv *dev, bool enable);

//--------------------------------------------------
// VBP
//--------------------------------------------------
int ifrtp_set_tx_vbp_default_mac_type(struct igw_priv *dev, struct IocTxVbpDefaultMacTypeInitConfig *config);
int ifrtp_set_tx_vbp_mac_type_bypass(struct igw_priv *dev, struct IocTxVbpMacTypeBypassInitConfig *config);
int ifrtp_set_tx_source_secondary_mac_address(struct igw_priv *dev, struct IocNetTxSourceMacAddressConfig *config);
int ifrtp_set_tx_source_secondary_address(struct igw_priv *dev, struct IocNetTxSourceIpAddressConfig *config);
int ifrtp_get_tx_source_secondary_address(struct igw_priv *dev, struct IocNetTxSourceIpAddressConfig *config);
int ifrtp_set_tx_dest_secondary_mac_address(struct igw_priv *dev, struct IocNetTxDestMacAddressConfig *config);
int ifrtp_get_tx_dest_secondary_mac_address(struct igw_priv *dev, struct IocNetTxDestMacAddressConfig *config);
int ifrtp_set_tx_dest_secondary_address(struct igw_priv *dev, struct IocNetTxDestIpAddressConfig *config);
int ifrtp_get_tx_dest_secondary_address(struct igw_priv *dev, struct IocNetTxDestIpAddressConfig *config);
int ifrtp_set_tx_secondary_port(struct igw_priv *dev, struct IocNetTxPortConfig *config);
int ifrtp_get_tx_secondary_port(struct igw_priv *dev, struct IocNetTxPortConfig *config);
int ifrtp_set_tx_duplicate_enable(struct igw_priv *dev, struct IocNetTxDuplicateEnableConfig *config);

//--------------------------------------------------
// Stream Transmitter
//--------------------------------------------------
int ifrtp_set_tx_strm_trns_chnl(struct igw_priv *dev, struct IocStrmTrnsCnlInitConfig *config);
int ifrtp_set_tx_strm_trns_chnl_ctl(struct igw_priv *dev, struct IocStrmTrnsCnlCtlInitConfig *config);
int ifrtp_set_tx_source_primary_mac_address(struct igw_priv *dev, struct IocNetTxSourceMacAddressConfig *config);
int ifrtp_set_tx_source_primary_address(struct igw_priv *dev, struct IocNetTxSourceIpAddressConfig *config);
int ifrtp_get_tx_source_primary_address(struct igw_priv *dev, struct IocNetTxSourceIpAddressConfig *config);
int ifrtp_set_tx_dest_primary_mac_address(struct igw_priv *dev, struct IocNetTxDestMacAddressConfig *config);
int ifrtp_get_tx_dest_primary_mac_address(struct igw_priv *dev, struct IocNetTxDestMacAddressConfig *config);
int ifrtp_set_tx_dest_primary_address(struct igw_priv *dev, struct IocNetTxDestIpAddressConfig *config);
int ifrtp_get_tx_dest_primary_address(struct igw_priv *dev, struct IocNetTxDestIpAddressConfig *config);
int ifrtp_set_tx_primary_port(struct igw_priv *dev, struct IocNetTxPortConfig *config);
int ifrtp_get_tx_primary_port(struct igw_priv *dev, struct IocNetTxPortConfig *config);

//--------------------------------------------------
// Validation
//--------------------------------------------------
int ifrtp_set_rx_validation(struct igw_priv *dev, struct IocPktValidationRxInitConfig *config);

//--------------------------------------------------
// Extraction
//--------------------------------------------------
int ifrtp_set_rx_extraction(struct igw_priv *dev, struct IocPayloadExtractionRxInitConfig *config);
void ifrtp_set_rx_extraction_dual_ssrc(struct igw_priv *dev, struct IocPayloadExtractionRxSSRCConfig *config);
int ifrtp_get_rx_sequence_number_error_status(struct igw_priv *dev, struct IocNetRxSequenceNumberErrorStatusConfig *config);

//--------------------------------------------------
// Identification
//--------------------------------------------------
int ifrtp_set_rx_identification(struct igw_priv *dev, struct IocIdentificationRxInitConfig *config);
int ifrtp_get_rx_identification(struct igw_priv *dev, struct IocIdentificationRxInitConfig *config);
int ifrtp_set_rx_dest_address(struct igw_priv *dev, struct IocNetRxDestIpAddressConfig *config);
int ifrtp_get_rx_dest_address(struct igw_priv *dev, struct IocNetRxDestIpAddressConfig *config);
int ifrtp_set_rx_port(struct igw_priv *dev, struct IocNetRxPortConfig *config);
int ifrtp_get_rx_port(struct igw_priv *dev, struct IocNetRxPortConfig *config);
int ifrtp_set_rx_filter_enable(struct igw_priv *dev);
int ifrtp_enable_stream_filter(struct igw_priv *dev);

//--------------------------------------------------
// TRM
//--------------------------------------------------
int ifrtp_enable_rx_trm_bucket(struct igw_priv *dev);
int ifrtp_init_rx_trm_ctrl_bucket_init(struct igw_priv *dev);
int ifrtp_set_rx_trm_ctrl_bucket_init(struct igw_priv *dev, struct IocNetRxTrmCtrlBucketInitConfig *config);

//--------------------------------------------------
// XGMAC
//--------------------------------------------------
unsigned int ifrtp_get_rx_xgmac_good_frame_lower(struct igw_priv *dev);

// transmitter system
void ifrtp_transmitter_system_enable(struct igw_priv *dev);

// receiver system
void ifrtp_receiver_system_enable(struct igw_priv *dev);

#endif /* IGW_NETWORK_H_ */
