// SPDX-License-Identifier: GPL-2.0
/*
 * Sony ifrtp SFP Ethernet device driver
 *
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#include <linux/io.h>
#include <linux/ioport.h>
#include <linux/platform_device.h>
#include <linux/of_address.h>
#include <linux/of_device.h>
#include <linux/of_platform.h>
#include <linux/irqreturn.h>
#include <linux/io.h>

#include "igw_driver.h"
#include "io.h"
#include "ifrtp.h"
#include "ifrtp_driver.h"
#include "irq.h"
#include "ifrtp_mdio.h"
#include "ifrtp_address.h"
#include "igw_net_address.h"

u8 __iomem *io_remapped, *led_io;

int ifrtp_led_on(unsigned int index)
{
	if (!IS_ERR(led_io)) {
		iowrite32(1, led_io + index * 4);
	} else {
		return PTR_ERR(led_io);
	}
	return 0;
}

int ifrtp_led_off(unsigned int index)
{
	if (!IS_ERR(led_io)) {
		iowrite32(0, led_io + index * 4);
	} else {
		return PTR_ERR(led_io);
	}
	return 0;
}

void ifrtp_irq_disable(struct igw_driver_handle *handle)
{
	ifrtp_disable_all_net_irq(handle->dev[0]);
}

void ifrtp_irq_clear(struct igw_driver_handle *handle)
{
}

bool ifrtp_irq_get_raw_packet(struct igw_priv *dev)
{
	return ifrtp_get_net_raw_packet_irq_status(dev);
}

void ifrtp_irq_clear_raw_packet(struct igw_priv *dev)
{
}

void ifrtp_irq_enable_raw_packet(struct igw_priv *dev)
{
	ifrtp_enable_net_raw_packet_irq(dev);
}

void ifrtp_irq_disable_raw_packet(struct igw_priv *dev)
{
	ifrtp_disable_net_raw_packet_irq(dev);
}

extern struct ifrtp_config ifrtp_cfg;
bool ifrtp_sfp_is_linked_up(struct igw_priv *dev)
{
	u32 lane_status = ifrtp_ior32(NULL, FPGA_MII_COMMON + IFRTP_OFFSET_SFP_LINKSTATE + dev->netif_priority * IFRTP_OFFSET_SFP_LINKSTATE_CH);

	if ((lane_status & IFRTP_SFP_LINKSTATE_BIT) && ifrtp_mdio_sfp_is_linked_up(dev->netif_priority))
		return true;
	else
		return false;
}

int ifrtp_sfp_get_linkspeed(struct igw_priv *dev)
{
	return NET_LINKSPEED_1G;
}

