/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2023 Sony Corporation. All rights reserved.
 */
#ifndef IFRTP_IO_H_
#define IFRTP_IO_H_

#include "i2c.h"
#include "igw_driver.h"

#define NET_LINKSPEED_1G        1000
#define NET_LINKSPEED_10G      10000
#define NET_LINKSPEED_UNKNOWN -1

extern u8 __iomem *io_remapped, *led_io;

int ifrtp_led_on(unsigned int index);
int ifrtp_led_off(unsigned int index);

static inline int ifrtp_iow32(struct igw_priv *dev, unsigned int data, unsigned int address)
{
	iowrite32(data, io_remapped + address);
	return 0;
}

static inline int ifrtp_memcpy_toio(struct igw_priv *dev, unsigned int *data_buf, unsigned int address, const unsigned int burst_count)
{
	memcpy_toio(io_remapped + address, data_buf, burst_count * 4);
	return 0;
}

static inline unsigned int ifrtp_ior32(struct igw_priv *dev, unsigned int address)
{
	return ioread32(io_remapped + address);
}

static inline int ifrtp_memcpy_fromio(struct igw_priv *dev, unsigned int *data_buf, unsigned int address, const unsigned int burst_count)
{
	memcpy_fromio(data_buf, io_remapped + address, burst_count * 4);
	return 0;
}


void ifrtp_irq_disable(struct igw_driver_handle *handle);
void ifrtp_irq_clear(struct igw_driver_handle *handle);

bool ifrtp_irq_get_raw_packet(struct igw_priv *dev);

void ifrtp_irq_clear_raw_packet(struct igw_priv *dev);

void ifrtp_irq_enable_raw_packet(struct igw_priv *dev);

void ifrtp_irq_disable_raw_packet(struct igw_priv *dev);

bool ifrtp_sfp_is_linked_up(struct igw_priv *dev);
int ifrtp_sfp_get_linkspeed(struct igw_priv *dev);

#endif // IFRTP_IO_H_
